@@ -17,10 +17,15 @@ class BBBDLC:
         }
 
         try:
-            os.setgid(10000)
-            os.setuid(1005)
+            os.chdir(args.ncDir)
+
             occCommand = "/opt/plesk/php/7.3/bin/php " + args.ncDir + "/occ "
-            ncPath = subprocess.check_output(occCommand + "config:system:get datadirectory", shell=True).decode('utf-8').strip()
+            os.system(occCommand + "config:system:get datadirectory >> ncPath.txt")
+
+            ncPathFile = open(args.ncDir + "ncPath.txt", "r")
+            ncPath = ncPathFile.readline()
+            ncPathFile.close()
+            os.system("rm " + args.ncDir + "ncPath.txt")
 
             if ncPath == "": raise NameError('Could not find nextcloud config!')
             
@@ -49,7 +54,18 @@ class BBBDLC:
             errorLog = open("/var/www/vhosts/sapienslab.com.mx/logs/bbb_error_log", "a")
             errorLog.write(error)
             errorLog.close()
-        
+
+def change(user_uid, user_gid):
+    def result():
+        report_ids('starting demotion')
+        os.setgid(user_gid)
+        os.setuid(user_uid)
+        report_ids('finished demotion')
+    return result
+
+def report_ids(msg):
+    print('uid, gid = %d, %d; %s' % (os.getuid(), os.getgid(), msg))
+
 def get_parent(dirName, dirUp):
     for i in range(dirUp):
         dirName = os.path.dirname(dirname)
